@@ -111,7 +111,7 @@ class Email(Field):
         domain_list: list[str] = data.email_domain,
     ) -> None:
         """
-        :param length_range: the range of the email's length, but does not include the length of prefix,. Notice the last number will not in the range
+        :param length_range: the range of the email's length, but does not include the length of prefix. Notice the last number will not in the range
         :param prefix: the prefix of every email
         :param allow: allowed characters
         :param domain_list: the domain name list
@@ -134,7 +134,7 @@ class Email(Field):
         return self.value
 
 
-class Birth(Field):
+class BirthInfo(Field):
     def __init__(
         self, birth_year_range: range = range(1920, 2001), date_format: str = "%Y/%m/%d"
     ) -> None:
@@ -153,7 +153,7 @@ class Birth(Field):
         """
         Generate random birthday within the given range.
 
-        :return <tuple[str, int]>. The string is the random birthday, and the integer is the age.
+        :return: <tuple[str, int]>. The string is the random birthday, and the integer is the age.
         """
         start = datetime.date(self.birth_year_range[0], 1, 1)
         end = datetime.date(self.birth_year_range[-1], 12, 31)
@@ -214,19 +214,34 @@ class Location(Field):
     ) -> None:
         """
         :param location_list: location list
-        :param timezone_range: the range of timezone
         """
-        self.location = None
-        self.timezone = None  # timezone doesn't comply to the location
+        self.value = None
         self.location_list = location_list
         self.timezone_range = timezone_range
 
-    def generate(self) -> tuple[str, str]:
+    def generate(self) -> str:
         """
         Generate random location.
 
-        :return: tuple[str, str]. The first string is the location, and the second is the timezone offset.
+        :return: <str>
         """
-        self.location = random.choice(self.location_list)
-        self.timezone = "%+d" % (random.choice(self.timezone_range))
-        return (self.location, self.timezone)
+        self.value = random.choice(self.location_list)
+        return self.value
+
+
+class Timezone(Field):
+    def __init__(self, timezone_range: range = range(-24, 25)) -> None:
+        """
+        :param timezone_range: the range of timezone
+        """
+        self.value = None
+        self.timezone_range = timezone_range
+
+    def generate(self) -> str:
+        """
+        Generate random timezone.
+
+        :return: <str>
+        """
+        self.value = "%+d" % (random.choice(self.timezone_range))
+        return self.value
